@@ -17,8 +17,8 @@ $Carp::Internal{ (__PACKAGE__) }++;
 #$Carp::Internal{ (__Errorlog__) }++;
 
 
-my $version = '$Id: Errorlog.pm 43775 2015-08-26 07:48:11Z anton $ ';
-our $VERSION = "1.43";
+my $version = '$Id: Errorlog.pm 43978 2015-10-07 09:38:53Z anton $ ';
+our $VERSION = "1.44";
 
 #global variable, needed for TeeOutput
 our $SELF;
@@ -522,15 +522,17 @@ sub overrule {
 	my $fh = new FileHandle();
 	my $configdir = $self->field('configdir');
 
+	my $outputString = '';
+
 	return unless $configdir;
 	if (-d $configdir) {
 		foreach $basepart ('defaults', $self->basefilename(), 'overrule') {
 			$configfile = "$configdir/${basepart}_errorlog.cf";
 			next unless -r $configfile;
-			warn "Using additional configfile: $configfile" if $Baseobject::verbosity >= 2 ;
+			$outputString .= "Using additional configfile: $configfile" if $Baseobject::verbosity >= 2 ;
 
 			unless (open ($fh, $configfile)) {
-				warn "Found but could not open configfile: $configfile, $!";
+				carp "Found but could not open configfile: $configfile, $!";
 				return;
 			}
 
@@ -546,13 +548,11 @@ sub overrule {
 
 				if ($name eq 'verbosity') {
 					verbosity($value);
-					my $froozen = '';
 					if ($split eq '=') {
 						freezeverbosity(1);
-						$froozen = '(froozen)';
 					}
 
-					carp "Configfile: $configfile, verbosity: $value " if $Baseobject::verbosity >= 2;
+					$outputString .= "Configfile: $configfile, verbosity: $value " if $Baseobject::verbosity >= 2;
 					next;
 				}
 
@@ -575,12 +575,14 @@ sub overrule {
 					warn "ignoring variable: $name: type \"$ref\" not supported";
 				}
 			}
-			warn "Errorlog (version: $VERSION): Using configfile: $configfile" 
-				if $Baseobject::verbosity > 1 or $self->error();
+			$outputString .= "Errorlog (version: $VERSION): Using configfile: $configfile";
 		}
 	} else {
 		warn "Warning; Errorlog (version: $VERSION) configdir: \"$configdir\" does not exist";
 	}
+
+	warn $outputString if $Baseobject::verbosity >= 2 or $self->error();
+
 }
 
 sub uniquelist {
